Learn R Programming

specL (version 1.4.0)

cdsw: Generate Dynamic SWATH Window

Description

This function generates an ion library for SWATH analysis. It takes a R data object which contains a peak list. The R data object can be generated using the read.bibliospec function.

Usage

cdsw(x, n=20, overlap=1)

Arguments

x
Numeric vector or psmSet class.
n
Number of desired SWATH windows.
overlap
Overlap of SWATH windows. The default is 1 Dalton

Value

The output is table containing having the attributes from, to, mid, width, and counts. In the idea output all bins should contain the same number of numeric values.

Details

The function determines the SWATH windows using the quantile function.

See Also

The S3 class definition: showClass("psmSet")

Examples

Run this code

  cdsw(peptideStd)
  

Run the code above in your browser using DataLab