This function reads a BiblioSpec generated file and returns
a list of tandem mass specs (psm objects),
peptide assignments, retention times, and
modifications records. The type of the data structire which is
returned is called psmSet.
Usage
read.bibliospec(file, ncores = NULL)
Arguments
file
the name of the BiblioSpec generated SQLite file.
Value
It returns a list which can be read by the genSwathIonLib
function and the protViz::peakplot function.
Details
The function performs a SQL query on the SQLite files generated by
bibliospec using the RSQLite package.
The function is required for generating spec libraries used
in a SWATH workflow.